@@ -9,6 +9,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
@@ -18,11 +21,12 @@
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
+# include "config/vxworks-dummy.h"
 # include "config/rs6000/biarch64.h"
 # include "config/rs6000/rs6000.h"
-# include "config/dbxelf.h"
 # include "config/elfos.h"
 # include "config/gnu-user.h"
+# include "config/linux.h"
 # include "config/freebsd-spec.h"
 # include "config/rs6000/sysv4.h"
 # include "config/rs6000/default64.h"
@@ -37,8 +41,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
